@@ -3,9 +3,11 @@ from .alphafold import AlphaFold
 from .bowtie2 import Bowtie2
 from .cellranger import CellRangerCount
 from .clustalo import ClustalO
+from .diamond import DiamondBlastp, DiamondBlastx
 from .demucs import Demucs
 from .kraken2 import Kraken2
 from .megahit import Megahit
+from .rapsearch2 import Rapsearch2
 from .shi7 import Shi7
 from .shogun import ShogunAlign, ShogunFilter
 from .star import STARInstance
