@@ -5,6 +5,7 @@ toolchest_client.tools.cellranger
 This contains the cellranger implementations of the Tool class.
 """
 from . import Tool
+from toolchest_client.files import OutputType
 
 
 class CellRangerCount(Tool):
@@ -12,7 +13,7 @@ class CellRangerCount(Tool):
     The cellranger_count implementation of the Tool class.
     """
     def __init__(self, tool_args, output_name, inputs, output_path,
-                 database_name, database_version):
+                 database_name, database_version, **kwargs):
         super().__init__(
             tool_name="cellranger_count",
             tool_version="6.1.2",  # todo: allow cellranger version to be set by the user
@@ -26,4 +27,7 @@ class CellRangerCount(Tool):
             database_version=database_version,
             compress_inputs=True,
             max_input_bytes_per_file=128 * 1024 * 1024 * 1024,
+            output_type=OutputType.GZ_TAR,
+            output_is_directory=True,
+            **kwargs,
         )
